@@ -4,4 +4,4 @@ from pregex.core import groups as gr
 from pregex.core import operators as op
 from pregex.core import quantifiers as qu
 from pregex.core import tokens as tk
-from pregex.core.pre import Pregex, Empty
\ No newline at end of file
+from pregex.core.pre import Pregex
\ No newline at end of file
